pub struct Data {
pub txs: Vec<Vec<u8>>,
pub square_size: u64,
pub hash: Vec<u8>,
}Expand description
Data contained in a Block.
Fields
txs: Vec<Vec<u8>>Transactions.
square_size: u64Square width of original data square.
hash: Vec<u8>Hash is the root of a binary Merkle tree where the leaves of the tree are the row and column roots of an extended data square. Hash is often referred to as the “data root”.