CommitExt

Trait CommitExt 

pub trait CommitExt {
    // Required method
    fn vote_sign_bytes(
        &self,
        chain_id: &Id,
        signature_idx: usize,
    ) -> Result<Vec<u8>>;
}
An extension trait for the Commit to perform additional actions.

Required Methods

fn vote_sign_bytes( &self, chain_id: &Id, signature_idx: usize, ) -> Result<Vec<u8>>

Get the signed Vote from the Commit at the given index.

Implementations on Foreign Types

Source

impl CommitExt for Commit

Source

fn vote_sign_bytes( &self, chain_id: &Id, signature_idx: usize, ) -> Result<Vec<u8>>

Implementors