NamespaceDataId

Struct NamespaceDataId 

pub struct NamespaceDataId { /* private fields */ }
Identifies Shares within a Namespace located on block’s ExtendedDataSquare.

Implementations

Source

impl NamespaceDataId

pub fn new(namespace: Namespace, block_height: u64) -> Result<Self>

Create a new NamespaceDataId for given block and the Namespace.

Errors

This function will return an error if the block height is invalid.

pub fn block_height(&self) -> u64

A height of the block which contains the shares.

pub fn namespace(&self) -> Namespace

A namespace of the Shares.

pub fn encode(&self, bytes: &mut BytesMut)

Encode row namespace data id into the byte representation.

pub fn decode(buffer: &[u8]) -> Result<Self>

Decode namespace data id from the byte representation.