pub struct BaseAccount {
pub address: AccAddress,
pub pub_key: Option<PublicKey>,
pub account_number: u64,
pub sequence: u64,
}Expand description
BaseAccount defines a base account type.
It contains all the necessary fields for basic account functionality.
Any custom account type should extend this type for additional functionality (e.g. vesting).
Fields
address: AccAddressBech32 AccountId of this account.
pub_key: Option<PublicKey>Optional PublicKey associated with this account.
account_number: u64account_number is the account number of the account in state
sequence: u64Sequence of the account, which describes the number of committed transactions signed by a given address.