ErrorCode

Enum ErrorCode 

#[repr(u32)]
pub enum ErrorCode {
Show 71 variants Success = 0, TxDecode = 2, InvalidSequence = 3, Unauthorized = 4, InsufficientFunds = 5, UnknownRequest = 6, InvalidAddress = 7, InvalidPubKey = 8, UnknownAddress = 9, InvalidCoins = 10, OutOfGas = 11, MemoTooLarge = 12, InsufficientFee = 13, TooManySignatures = 14, NoSignatures = 15, JSONMarshal = 16, JSONUnmarshal = 17, InvalidRequest = 18, TxInMempoolCache = 19, MempoolIsFull = 20, TxTooLarge = 21, KeyNotFound = 22, WrongPassword = 23, InvalidSigner = 24, InvalidGasAdjustment = 25, InvalidHeight = 26, InvalidVersion = 27, InvalidChainID = 28, InvalidType = 29, TxTimeoutHeight = 30, UnknownExtensionOptions = 31, WrongSequence = 32, PackAny = 33, UnpackAny = 34, Logic = 35, Conflict = 36, NotSupported = 37, NotFound = 38, IO = 39, AppConfig = 40, InvalidGasLimit = 41, Panic = 111_222, ReservedNamespace = 11_110, InvalidNamespaceLen = 11_111, InvalidDataSize = 11_112, BlobSizeMismatch = 11_113, CommittedSquareSizeNotPowOf2 = 11_114, CalculateCommitment = 11_115, InvalidShareCommitment = 11_116, ParitySharesNamespace = 11_117, TailPaddingNamespace = 11_118, TxNamespace = 11_119, InvalidShareCommitments = 11_122, UnsupportedShareVersion = 11_123, ZeroBlobSize = 11_124, MismatchedNumberOfPFBorBlob = 11_125, NoPFB = 11_126, NamespaceMismatch = 11_127, ProtoParsing = 11_128, MultipleMsgsInBlobTx = 11_129, MismatchedNumberOfPFBComponent = 11_130, NoBlobs = 11_131, NoNamespaces = 11_132, NoShareVersions = 11_133, NoBlobSizes = 11_134, NoShareCommitments = 11_135, InvalidNamespace = 11_136, InvalidNamespaceVersion = 11_137, TotalBlobSizeTooLarge = 11_138, BlobsTooLarge = 11_139, InvalidBlobSigner = 11_140,
}
Error codes associated with transaction responses.

Variants



Success = 0

No error



TxDecode = 2

Cannot parse a transaction



InvalidSequence = 3

Sequence number (nonce) is incorrect for the signature



Unauthorized = 4

Request without sufficient authorization is handled



InsufficientFunds = 5

Account cannot pay requested amount



UnknownRequest = 6

Request is unknown



InvalidAddress = 7

Address is invalid



InvalidPubKey = 8

Pubkey is invalid



UnknownAddress = 9

Address is unknown



InvalidCoins = 10

Coin is invalid



OutOfGas = 11

Gas exceeded



MemoTooLarge = 12

Memo too large



InsufficientFee = 13

Fee is insufficient



TooManySignatures = 14

Too many signatures



NoSignatures = 15

No signatures in transaction



JSONMarshal = 16

Error converting to json



JSONUnmarshal = 17

Error converting from json



InvalidRequest = 18

Request contains invalid data



TxInMempoolCache = 19

Tx already exists in the mempool



MempoolIsFull = 20

Mempool is full



TxTooLarge = 21

Tx is too large



KeyNotFound = 22

Key doesn’t exist



WrongPassword = 23

Key password is invalid



InvalidSigner = 24

Tx intended signer does not match the given signer



InvalidGasAdjustment = 25

Invalid gas adjustment



InvalidHeight = 26

Invalid height



InvalidVersion = 27

Invalid version



InvalidChainID = 28

Chain-id is invalid



InvalidType = 29

Invalid type



TxTimeoutHeight = 30

Tx rejected due to an explicitly set timeout height



UnknownExtensionOptions = 31

Unknown extension options.



WrongSequence = 32

Account sequence defined in the signer info doesn’t match the account’s actual sequence



PackAny = 33

Packing a protobuf message to Any failed



UnpackAny = 34

Unpacking a protobuf message from Any failed



Logic = 35

Internal logic error, e.g. an invariant or assertion that is violated



Conflict = 36

Conflict error, e.g. when two goroutines try to access the same resource and one of them fails



NotSupported = 37

Called a branch of a code which is currently not supported



NotFound = 38

Requested entity doesn’t exist in the state



IO = 39

Internal errors caused by external operation



AppConfig = 40

Min-gas-prices field in BaseConfig is empty



InvalidGasLimit = 41

Invalid GasWanted value is supplied



Panic = 111_222

Node recovered from panic



ReservedNamespace = 11_110

cannot use reserved namespace IDs



InvalidNamespaceLen = 11_111

invalid namespace length



InvalidDataSize = 11_112

data must be multiple of shareSize



BlobSizeMismatch = 11_113

actual blob size differs from that specified in the MsgPayForBlob



CommittedSquareSizeNotPowOf2 = 11_114

committed to invalid square size: must be power of two



CalculateCommitment = 11_115

unexpected error calculating commitment for share



InvalidShareCommitment = 11_116

invalid commitment for share



ParitySharesNamespace = 11_117

cannot use parity shares namespace ID



TailPaddingNamespace = 11_118

cannot use tail padding namespace ID



TxNamespace = 11_119

cannot use transaction namespace ID



InvalidShareCommitments = 11_122

invalid share commitments: all relevant square sizes must be committed to



UnsupportedShareVersion = 11_123

unsupported share version



ZeroBlobSize = 11_124

cannot use zero blob size



MismatchedNumberOfPFBorBlob = 11_125

mismatched number of blobs per MsgPayForBlob



NoPFB = 11_126

no MsgPayForBlobs found in blob transaction



NamespaceMismatch = 11_127

namespace of blob and its respective MsgPayForBlobs differ



ProtoParsing = 11_128

failure to parse a transaction from its protobuf representation



MultipleMsgsInBlobTx = 11_129

not yet supported: multiple sdk.Msgs found in BlobTx



MismatchedNumberOfPFBComponent = 11_130

number of each component in a MsgPayForBlobs must be identical



NoBlobs = 11_131

no blobs provided



NoNamespaces = 11_132

no namespaces provided



NoShareVersions = 11_133

no share versions provided



NoBlobSizes = 11_134

no blob sizes provided



NoShareCommitments = 11_135

no share commitments provided



InvalidNamespace = 11_136

invalid namespace



InvalidNamespaceVersion = 11_137

invalid namespace version



TotalBlobSizeTooLarge = 11_138

total blob size too large

TotalBlobSize is deprecated, use BlobsTooLarge instead.



BlobsTooLarge = 11_139

blob(s) too large



InvalidBlobSigner = 11_140

invalid blob signer