pub struct AbciQueryResponse {
pub height: Height,
pub code: ErrorCode,
pub codespace: String,
pub index: u64,
pub key: Vec<u8>,
pub value: Vec<u8>,
pub proof_ops: Option<ProofOps>,
pub log: String,
pub info: String,
}Expand description
Response to a tx query
Fields
height: HeightThe block height from which data was derived.
Note that this is the height of the block containing the application’s Merkle root hash, which represents the state as it was after committing the block at height - 1.
code: ErrorCodeResponse code.
codespace: StringNamespace for the Code.
index: u64The index of the key in the tree.
key: Vec<u8>The key of the matching data.
value: Vec<u8>The value of the matching data.
proof_ops: Option<ProofOps>Serialized proof for the value data, if requested,
to be verified against the AppHash for the given Height.
log: StringThe output of the application’s logger (raw string). May be non-deterministic.
info: StringAdditional information. May be non-deterministic.