Fee

Struct Fee 

pub struct Fee {
    pub amount: Vec<Coin>,
    pub gas_limit: u64,
    pub payer: Option<Address>,
    pub granter: Option<Address>,
}
Fee includes the amount of coins paid in fees and the maximum gas to be used by the transaction. The ratio yields an effective “gasprice”, which must be above some miminum to be accepted into the mempool.

Fields

amount: Vec<Coin>

amount is the amount of coins to be paid as a fee

gas_limit: u64

gas_limit is the maximum gas that can be used in transaction processing before an out of gas error occurs

payer: Option<Address>

if unset, the first signer is responsible for paying the fees. If set, the specified account must pay the fees. the payer must be a tx signer (and thus have signed this field in AuthInfo). setting this field does not change the ordering of required signers for the transaction.

granter: Option<Address>

if set, the fee payer (either the first signer or the value of the payer field) requests that a fee grant be used to pay fees instead of the fee payer’s own balance. If an appropriate fee grant does not exist or the chain does not support fee grants, this will fail

Implementations

Source

impl Fee

pub fn new(utia_fee: u64, gas_limit: u64) -> Self

Create Fee struct with provided number of utia and gas limit, without setting custom Fee::payer or Fee::granter fields, which means first tx signer is responsible for paying.