TxResponse

Struct TxResponse 

pub struct TxResponse {
Show 13 fields pub height: Height, pub txhash: Hash, pub codespace: String, pub code: ErrorCode, pub data: String, pub raw_log: String, pub logs: Vec<AbciMessageLog>, pub info: String, pub gas_wanted: i64, pub gas_used: i64, pub tx: Option<Any>, pub timestamp: String, pub events: Vec<Event>,
}
Response to a tx query

Fields

height: Height

The block height

txhash: Hash

The transaction hash.

codespace: String

Namespace for the Code

code: ErrorCode

Response code.

data: String

Result bytes, if any.

raw_log: String

The output of the application’s logger (raw string). May be non-deterministic.

logs: Vec<AbciMessageLog>

The output of the application’s logger (typed). May be non-deterministic.

info: String

Additional information. May be non-deterministic.

gas_wanted: i64

Amount of gas requested for transaction.

gas_used: i64

Amount of gas consumed by transaction.

tx: Option<Any>

The request transaction bytes.

timestamp: String

Time of the previous block. For heights > 1, it’s the weighted median of the timestamps of the valid votes in the block.LastCommit. For height == 1, it’s genesis time.

events: Vec<Event>

Events defines all the events emitted by processing a transaction. Note, these events include those emitted by processing all the messages and those emitted from the ante. Whereas Logs contains the events, with additional metadata, emitted only by processing the messages.