pub struct ExtendedHeaderGenerator { /* private fields */ }test-utils only.Expand description
ExtendedHeader generator for testing purposes.
WARNING: ALL METHODS PANIC! DO NOT USE IT IN PRODUCTION!
Implementations
Sourceimpl ExtendedHeaderGenerator
impl ExtendedHeaderGenerator
Sourcepub fn new() -> ExtendedHeaderGenerator
pub fn new() -> ExtendedHeaderGenerator
Creates new ExtendedHeaderGenerator.
Sourcepub fn new_from_height(height: u64) -> ExtendedHeaderGenerator
pub fn new_from_height(height: u64) -> ExtendedHeaderGenerator
Creates new ExtendedHeaderGenerator starting from specified height.
use celestia_types::test_utils::ExtendedHeaderGenerator;
let mut generator = ExtendedHeaderGenerator::new_from_height(5);
let header5 = generator.next();Sourcepub fn next(&mut self) -> ExtendedHeader
pub fn next(&mut self) -> ExtendedHeader
Generates the next header for a random non-empty data square.
use celestia_types::test_utils::ExtendedHeaderGenerator;
let mut generator = ExtendedHeaderGenerator::new();
let header1 = generator.next();Sourcepub fn next_empty(&mut self) -> ExtendedHeader
pub fn next_empty(&mut self) -> ExtendedHeader
Generates the next header for an empty data square.
use celestia_types::test_utils::ExtendedHeaderGenerator;
let mut generator = ExtendedHeaderGenerator::new();
let header1 = generator.next_empty();Sourcepub fn next_with_dah(&mut self, dah: DataAvailabilityHeader) -> ExtendedHeader
pub fn next_with_dah(&mut self, dah: DataAvailabilityHeader) -> ExtendedHeader
Generates the next header with the given DataAvailabilityHeader
use celestia_types::test_utils::ExtendedHeaderGenerator;
let mut generator = ExtendedHeaderGenerator::new();
let header1 = generator.next_with_dah(generate_dah());Sourcepub fn next_many(&mut self, amount: u64) -> Vec<ExtendedHeader>
pub fn next_many(&mut self, amount: u64) -> Vec<ExtendedHeader>
Generate the amount of subsequent non-empty headers.
Sourcepub fn next_many_empty(&mut self, amount: u64) -> Vec<ExtendedHeader>
pub fn next_many_empty(&mut self, amount: u64) -> Vec<ExtendedHeader>
Generate the amount of subsequent empty headers.
Sourcepub fn next_of(&self, header: &ExtendedHeader) -> ExtendedHeader
pub fn next_of(&self, header: &ExtendedHeader) -> ExtendedHeader
Generates the next header of the provided header.
This can be used to create two headers of same height but different hash.
use celestia_types::test_utils::ExtendedHeaderGenerator;
let mut generator = ExtendedHeaderGenerator::new();
let header1 = generator.next();
let header2 = generator.next();
let another_header2 = generator.next_of(&header1);Note
This method does not change the state of ExtendedHeaderGenerator.
Sourcepub fn next_of_with_dah(
&self,
header: &ExtendedHeader,
dah: DataAvailabilityHeader,
) -> ExtendedHeader
pub fn next_of_with_dah( &self, header: &ExtendedHeader, dah: DataAvailabilityHeader, ) -> ExtendedHeader
Generates the next header of the provided header with the given DataAvailabilityHeader.
This can be used to create two headers of same height but different hash.
use celestia_types::test_utils::ExtendedHeaderGenerator;
let mut generator = ExtendedHeaderGenerator::new();
let header1 = generator.next();
let header2 = generator.next();
let another_header2 = generator.next_of_with_dah(&header1, generate_dah());Note
This method does not change the state of ExtendedHeaderGenerator.
Sourcepub fn next_many_of(
&self,
header: &ExtendedHeader,
amount: u64,
) -> Vec<ExtendedHeader>
pub fn next_many_of( &self, header: &ExtendedHeader, amount: u64, ) -> Vec<ExtendedHeader>
Generates the next amount of headers of the provided header.
This can be used to create two chains of headers of same heights but different hashes.
use celestia_types::test_utils::ExtendedHeaderGenerator;
let mut generator = ExtendedHeaderGenerator::new();
let header1 = generator.next();
let headers_2_to_12 = generator.next_many(10);
let another_headers_2_to_12 = generator.next_many_of(&header1, 10);Note
This method does not change the state of ExtendedHeaderGenerator.
Sourcepub fn another_of(&self, header: &ExtendedHeader) -> ExtendedHeader
pub fn another_of(&self, header: &ExtendedHeader) -> ExtendedHeader
Generates the another header of the same height but different hash.
use celestia_types::test_utils::ExtendedHeaderGenerator;
let mut generator = ExtendedHeaderGenerator::new();
let header1 = generator.next();
let header2 = generator.next();
let another_header2 = generator.another_of(&header2);Note
This method does not change the state of ExtendedHeaderGenerator.
Sourcepub fn fork(&self) -> ExtendedHeaderGenerator
pub fn fork(&self) -> ExtendedHeaderGenerator
Create a “forked” generator for “forking” the chain.
use celestia_types::test_utils::ExtendedHeaderGenerator;
let mut gen_chain1 = ExtendedHeaderGenerator::new();
let header1 = gen_chain1.next();
let header2 = gen_chain1.next();
let mut gen_chain2 = gen_chain1.fork();
let header3_chain1 = gen_chain1.next();
let header3_chain2 = gen_chain2.next();Note
This is the same as clone, but the name describes the intention.
Sourcepub fn set_time(&mut self, time: Time, block_time: Duration)
pub fn set_time(&mut self, time: Time, block_time: Duration)
Change header generator time. Headers generated from now on will have time as creation
time.
Sourcepub fn reset_time(&mut self)
pub fn reset_time(&mut self)
Reset header generator time, so that it produces headers with current timestamp