pub struct BadEncodingFraudProof { /* private fields */ }Expand description
A proof that the block producer incorrectly encoded ExtendedDataSquare.
A malicious actor may incorrectly extend the original data with the recovery data, thus making it impossible to reconstruct the original information.
Light node cannot detect such behaviour with Data Availability Sampling.
When the full node collects all the Shares of a row or column of the ExtendedDataSquare
and detects that it was incorrectly encoded, it should create and announce
BadEncodingFraudProof so that light nodes can reject this block.