pub struct TxBody {
pub messages: Vec<Any>,
pub memo: String,
pub timeout_height: Height,
pub extension_options: Vec<Any>,
pub non_critical_extension_options: Vec<Any>,
}Expand description
TxBody of a transaction that all signers sign over.
Fields
messages: Vec<Any>messages is a list of messages to be executed. The required signers of
those messages define the number and order of elements in AuthInfo’s
signer_infos and Tx’s signatures. Each required signer address is added to
the list only the first time it occurs.
By convention, the first required signer (usually from the first message) is referred to as the primary signer and pays the fee for the whole transaction.
memo: Stringmemo is any arbitrary memo to be added to the transaction.
timeout_height: Heighttimeout is the block height after which this transaction will not
be processed by the chain
extension_options: Vec<Any>extension_options are arbitrary options that can be added by chains
when the default options are not sufficient. If any of these are present
and can’t be handled, the transaction will be rejected
non_critical_extension_options: Vec<Any>extension_options are arbitrary options that can be added by chains
when the default options are not sufficient. If any of these are present
and can’t be handled, they will be ignored