pub struct TxResponse {}Expand description
Response to a tx query
Fields
height: HeightThe block height
txhash: HashThe transaction hash.
codespace: StringNamespace for the Code
code: ErrorCodeResponse code.
data: StringResult bytes, if any.
raw_log: StringThe output of the application’s logger (raw string). May be non-deterministic.
logs: Vec<AbciMessageLog>The output of the application’s logger (typed). May be non-deterministic.
info: StringAdditional information. May be non-deterministic.
gas_wanted: i64Amount of gas requested for transaction.
gas_used: i64Amount of gas consumed by transaction.
tx: Option<Any>The request transaction bytes.
timestamp: StringTime of the previous block. For heights > 1, it’s the weighted median of the timestamps of the valid votes in the block.LastCommit. For height == 1, it’s genesis time.
events: Vec<Event>Events defines all the events emitted by processing a transaction. Note, these events include those emitted by processing all the messages and those emitted from the ante. Whereas Logs contains the events, with additional metadata, emitted only by processing the messages.